@@ -28,6 +28,7 @@ class Reader:
             self.__object = (buff, serialno, granulepos)
 
         def __iter__(self):
+            self.anx.anx.seek_time(0, ANX_SEEK_SET);
             return self
 
         def next(self):
@@ -56,6 +57,7 @@ class Reader:
             }
         self.__head = None
         self.__end_of_stream = 0
+
         def is_clip(x):
             return x.__class__ == Clip
         self.clips = self.__event_generator(self, is_clip)
@@ -63,14 +65,19 @@ class Reader:
     def __read_stream(self, anx, timebase, utc):
         self.__props["timebase"] = timebase
         self.__props["utc"] = utc
+        return ANX_CONTINUE
 
     def __read_head(self, anx, head):
         self.__props["head"] = head
+        return ANX_CONTINUE
 
     def _readmore(self):
-        x = self.anx.read(1024)
-        if x <= 0:
+        x = self.anx.read(102400)
+        if x > 0:
+            return
+        if x == 0:
             raise EndOfFile
+        return x
 
     def __getattr__(self, attr):
         if attr in self.__props:
