@@ -42,6 +42,7 @@ static PyObject * py_anx_get_basetime (PyObject * self);
 static PyObject * py_anx_get_presentation_time (PyObject * self);
 static PyObject * py_anx_get_bitrate (PyObject * self);
 static PyObject * py_anx_tell_time (PyObject * self);
+static PyObject * py_anx_seek_time (PyObject * self, PyObject *args);
 static PyObject * py_anx_writer_import(PyObject * self, PyObject * args,
 					   PyObject *kw);
 static void py_anx_dealloc(PyObject * self, PyObject * args);
@@ -108,6 +109,8 @@ static PyMethodDef anx_methods[] = {
 	  METH_VARARGS, "" },
 	{ "get_basetime", (PyCFunction)py_anx_get_basetime,
 	  METH_VARARGS, "" },
+	{ "seek_time", (PyCFunction)py_anx_seek_time,
+	  METH_VARARGS, "" },
 	{ "tell_time", (PyCFunction)py_anx_tell_time,
 	  METH_VARARGS, "" },
 	{ "writer_import", (PyCFunction)py_anx_writer_import, 
@@ -294,6 +297,20 @@ pyanchor_to_clip(PyObject *pyanchor, AnxClip *clip)
 	Py_DECREF(pyanchor);
 }
 
+static void
+pydesc_to_clip(PyObject *pydesc, AnxClip *clip)
+{
+    PyObject *cdata;
+
+    if (pydesc == NULL) return;
+  
+    cdata = get_object(pydesc, "cdata");
+    if (PyString_Check(cdata)) {
+        clip->desc_text = PyString_AsString(cdata);
+    }
+    Py_DECREF(pydesc);
+}
+
 static void
 pyclip_to_clip(PyObject *pyclip, AnxClip *clip)
 {
@@ -307,7 +324,7 @@ pyclip_to_clip(PyObject *pyclip, AnxClip *clip)
 	/* Img */
 
 	/* Desc */
-
+	pydesc_to_clip(get_object(pyclip, "desc"), clip);
 	/* Meta */
 }
 
@@ -364,6 +381,23 @@ py_anx_tell_time (PyObject * self)
   return PyFloat_FromDouble(ret);
 }
 
+/* Seek time */
+static PyObject *
+py_anx_seek_time (PyObject *self, PyObject *args)
+{
+	double ret;
+	double seconds;
+	int whence;
+
+	if (! PyArg_ParseTuple(args, "di", &seconds, &whence)) {
+		return NULL;
+	}
+
+	ret = anx_seek_time(PY_ANX(self)->anx, seconds, whence);
+
+	return PyFloat_FromDouble(ret);
+}
+
 /* Insert a clip */
 PyObject * 
 py_anx_insert_clip(PyObject * self, PyObject * args, PyObject *kw)
@@ -699,6 +733,43 @@ py_anxtrack_pyobject(const AnxTrack *track)
 	return pTrack;
 }
 
+
+
+static int
+end_callback(struct py_anx *py_anx, PyObject *ret)
+{
+	int result;
+
+	if (ret == NULL) {
+		py_anx->exception_occurred = 1;
+		return ANX_STOP_ERR;
+	}
+
+	if (ret == Py_None) {
+		result = ANX_STOP_OK;
+	} else if (PyObject_RichCompareBool(ret, 
+				     PyInt_FromLong(ANX_STOP_OK), 
+				     Py_EQ)) {
+		result = ANX_STOP_OK;
+	} else if (PyObject_RichCompareBool(ret, 
+					    PyInt_FromLong(ANX_CONTINUE), 
+					    Py_EQ)) {
+		result = ANX_CONTINUE;
+	} else if (PyObject_RichCompareBool(ret, 
+					    PyInt_FromLong(ANX_STOP_ERR), 
+					    Py_EQ)) {
+		result = ANX_STOP_ERR;
+	} else {
+		PyErr_SetString(annodex_error, 
+				"Callbacks must return one of ANX_STOP_OK, "
+				"ANX_CONTINUE or ANX_STOP_ERR");
+		py_anx->exception_occurred = 1;
+		result = ANX_STOP_ERR;
+	}
+	Py_DECREF(ret);
+	return result;
+}
+
 static int 
 AnxReadStream_callback (ANNODEX * annodex, double timebase, char * utc, void * user_data)
 {
@@ -715,12 +786,7 @@ AnxReadStream_callback (ANNODEX * annodex, double timebase, char * utc, void * u
 					    timebase, utc);
 	}
 
-	if (ret == NULL) {
-		py_anx->exception_occurred = 1;
-		return ANX_STOP_ERR;
-	} 
-
-	return ANX_CONTINUE;
+	return end_callback(py_anx, ret);
 }
 
 static int 
@@ -746,12 +812,7 @@ AnxReadTrack_callback (ANNODEX * annodex, long serialno,
 					    granule_rate_d, nr_header_packets);
 	}
 
-	if (ret == NULL) {
-		py_anx->exception_occurred = 1;
-		return ANX_STOP_ERR;
-	} 
-
-	return ANX_CONTINUE;
+	return end_callback(py_anx, ret);
 }
 
 /* This is the callback received from libannodex */
@@ -772,11 +833,8 @@ AnxReadHead_callback (ANNODEX * annodex, const AnxHead * head, void *user_data)
 		ret = PyObject_CallFunction(py_anx->head_callback, "OO", 
 					    (PyObject*) user_data, py_head);
 	}
-	if (ret == NULL) {
-		py_anx->exception_occurred = 1;
-		return ANX_STOP_ERR;
-	}
-	return ANX_CONTINUE;
+
+	return end_callback(py_anx, ret);
 }
 
 static int 
@@ -796,11 +854,8 @@ AnxReadClip_callback (ANNODEX * annodex, const AnxClip * clip, void * user_data)
 		ret = PyObject_CallFunction(py_anx->clip_callback, "OO", 
 					    (PyObject*) user_data, py_clip);
 	}
-	if (ret == NULL) {
-		py_anx->exception_occurred = 1;
-		return ANX_STOP_ERR;
-	}
-	return ANX_CONTINUE;
+	
+	return end_callback(py_anx, ret);
 }
 
 static int 
@@ -820,12 +875,7 @@ AnxReadRaw_callback (ANNODEX * annodex, unsigned char *buf, long n, long serialn
 					    buf, n, serialno, granulepos);
 	}
 
-	if (ret == NULL) {
-		py_anx->exception_occurred = 1;
-		return ANX_STOP_ERR;
-	} 
-
-	return ANX_CONTINUE;
+	return end_callback(py_anx, ret);
 }
 
 /* Do a callback */
